@@ -818,12 +818,17 @@ class EventInfo {
 public:
 
   /// Empty constructor.
-  EventInfo(): ordering(-1.0), coll(0), ok(false) {}
+  EventInfo(): code(0), ordering(-1.0), coll(0), ok(false) {}
 
-  /// The Event and info objects.
+  /// The Event object.
   Event event;
+
+  // The corresponding Info object.
   Info info;
 
+  /// The code for the subprocess.
+  int code;
+
   /// The ordering variable of this event.
   double ordering;
   bool operator<(const EventInfo & ei) const {
@@ -990,7 +995,7 @@ private:
   // Select the primary process.
   void select(Info & in) {
     primInfo = in;
-    primInfo.hiinfo = this;
+    primInfo.hiInfo = this;
   }
 
   // Accept an event and update statistics in info.
