@@ -1,5 +1,5 @@
 // Pythia.h is a part of the PYTHIA event generator.
-// Copyright (C) 2018 Torbjorn Sjostrand.
+// Copyright (C) 2019 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -10,19 +10,16 @@
 #define Pythia8_Pythia_H
 
 // Version number defined for use in macros and for consistency checks.
-#define PYTHIA_VERSION 8.240
-#define PYTHIA_VERSION_INTEGER 8240
+#define PYTHIA_VERSION 8.301
+#define PYTHIA_VERSION_INTEGER 8301
 
 // Header files for the Pythia class and for what else the user may need.
 #include "Pythia8/Analysis.h"
 #include "Pythia8/Basics.h"
 #include "Pythia8/BeamParticle.h"
-#include "Pythia8/BeamShape.h"
-#include "Pythia8/ColourReconnection.h"
 #include "Pythia8/Event.h"
 #include "Pythia8/FragmentationFlavZpT.h"
 #include "Pythia8/HadronLevel.h"
-#include "Pythia8/History.h"
 #include "Pythia8/Info.h"
 #include "Pythia8/JunctionSplitting.h"
 #include "Pythia8/LesHouches.h"
@@ -33,26 +30,31 @@
 #include "Pythia8/PartonDistributions.h"
 #include "Pythia8/PartonSystems.h"
 #include "Pythia8/PartonVertex.h"
+#include "Pythia8/PhysicsBase.h"
 #include "Pythia8/ProcessLevel.h"
 #include "Pythia8/PythiaStdlib.h"
 #include "Pythia8/ResonanceWidths.h"
 #include "Pythia8/RHadrons.h"
 #include "Pythia8/Ropewalk.h"
 #include "Pythia8/Settings.h"
+#include "Pythia8/ShowerModel.h"
 #include "Pythia8/SigmaTotal.h"
 #include "Pythia8/SimpleSpaceShower.h"
 #include "Pythia8/SimpleTimeShower.h"
 #include "Pythia8/SpaceShower.h"
 #include "Pythia8/StandardModel.h"
+#include "Pythia8/StringInteractions.h"
+#include "Pythia8/SusyCouplings.h"
 #include "Pythia8/SLHAinterface.h"
 #include "Pythia8/TimeShower.h"
 #include "Pythia8/UserHooks.h"
+#include "Pythia8/VinciaCommon.h"
 
 namespace Pythia8 {
 
 //==========================================================================
 
-// Forward declaration of HeavyIons and HIUserHooks classes.
+// Forward declaration of the HeavyIons and HIUserHooks classes.
 class HeavyIons;
 class HIUserHooks;
 
@@ -74,11 +76,12 @@ public:
   Pythia( istream& settingsStrings, istream& particleDataStrings,
     bool printBanner = true);
 
-  // Destructor. (See Pythia.cc file.)
-  ~Pythia();
+  // Destructor.
+  ~Pythia() {}
 
-  // Initialise new Pythia object (called by constructors).
-  void initPtrs();
+  // Copy and = constructors cannot be used.
+  Pythia(const Pythia&) = delete;
+  Pythia& operator=(const Pythia&) = delete;
 
   // Check consistency of version numbers (called by constructors).
   bool checkVersion();
@@ -97,61 +100,60 @@ public:
     return readFile(is, true, subrun);}
 
   // Possibility to pass in pointers to PDF's.
-  bool setPDFPtr( PDF* pdfAPtrIn, PDF* pdfBPtrIn, PDF* pdfHardAPtrIn = 0,
-    PDF* pdfHardBPtrIn = 0, PDF* pdfPomAPtrIn = 0, PDF* pdfPomBPtrIn = 0,
-    PDF* pdfGamAPtrIn = 0, PDF* pdfGamBPtrIn = 0, PDF* pdfHardGamAPtrIn = 0,
-    PDF* pdfHardGamBPtrIn = 0, PDF* pdfUnresAPtrIn = 0,
-    PDF* pdfUnresBPtrIn = 0, PDF* pdfUnresGamAPtrIn = 0,
-    PDF* pdfUnresGamBPtrIn = 0, PDF* pdfVMDAPtrIn = 0, PDF* pdfVMDBPtrIn = 0);
-  bool setPDFAPtr( PDF* pdfAPtrIn );
-  bool setPDFBPtr( PDF* pdfBPtrIn );
+  bool setPDFPtr( PDFPtr pdfAPtrIn, PDFPtr pdfBPtrIn,
+    PDFPtr pdfHardAPtrIn = nullptr, PDFPtr pdfHardBPtrIn = nullptr,
+    PDFPtr pdfPomAPtrIn = nullptr, PDFPtr pdfPomBPtrIn = nullptr,
+    PDFPtr pdfGamAPtrIn = nullptr, PDFPtr pdfGamBPtrIn = nullptr,
+    PDFPtr pdfHardGamAPtrIn = nullptr, PDFPtr pdfHardGamBPtrIn = nullptr,
+    PDFPtr pdfUnresAPtrIn = nullptr, PDFPtr pdfUnresBPtrIn = nullptr,
+    PDFPtr pdfUnresGamAPtrIn = nullptr, PDFPtr pdfUnresGamBPtrIn = nullptr,
+    PDFPtr pdfVMDAPtrIn = nullptr, PDFPtr pdfVMDBPtrIn = nullptr);
+  bool setPDFAPtr( PDFPtr pdfAPtrIn );
+  bool setPDFBPtr( PDFPtr pdfBPtrIn );
 
   // Set photon fluxes externally. Used with option "PDF:lepton2gammaSet = 2".
-  bool setPhotonFluxPtr( PDF* photonFluxAIn, PDF* photonFluxBIn) {
-    if ( photonFluxAIn != 0 ) pdfGamFluxAPtr = photonFluxAIn;
-    if ( photonFluxBIn != 0 ) pdfGamFluxBPtr = photonFluxBIn;
+  bool setPhotonFluxPtr( PDFPtr photonFluxAIn, PDFPtr photonFluxBIn) {
+    if ( photonFluxAIn ) pdfGamFluxAPtr = photonFluxAIn;
+    if ( photonFluxBIn ) pdfGamFluxBPtr = photonFluxBIn;
     return true;}
 
   // Possibility to pass in pointer to external LHA-interfaced generator.
-  bool setLHAupPtr( LHAup* lhaUpPtrIn) {lhaUpPtr = lhaUpPtrIn; return true;}
+  bool setLHAupPtr( LHAupPtr lhaUpPtrIn) {lhaUpPtr = lhaUpPtrIn;
+    useNewLHA = false; return true;}
 
   // Possibility to pass in pointer for external handling of some decays.
-  bool setDecayPtr( DecayHandler* decayHandlePtrIn,
+  bool setDecayPtr( DecayHandlerPtr decayHandlePtrIn,
     vector<int> handledParticlesIn) {decayHandlePtr = decayHandlePtrIn;
-    handledParticles.resize(0);
-    for (int i = 0; i < int(handledParticlesIn.size()); ++i)
-      handledParticles.push_back( handledParticlesIn[i] );
-    return true;}
+    handledParticles = handledParticlesIn; return true;}
 
   // Possibility to pass in pointer for external random number generation.
   bool setRndmEnginePtr( RndmEngine* rndmEnginePtrIn)
     { return rndm.rndmEnginePtr( rndmEnginePtrIn);}
 
   // Possibility to pass in pointer for user hooks.
-  bool setUserHooksPtr( UserHooks* userHooksPtrIn) {
-    if (hasUserHooksVector) delete userHooksPtr;
-    hasUserHooksVector = false;
+  bool setUserHooksPtr(UserHooksPtr userHooksPtrIn) {
     userHooksPtr = userHooksPtrIn; return true;}
 
   // Possibility to add further pointers to allow multiple user hooks.
-  bool addUserHooksPtr( UserHooks* userHooksPtrIn) {
+  bool addUserHooksPtr( UserHooksPtr userHooksPtrIn) {
+    if ( !userHooksPtrIn ) return false;
     if ( !userHooksPtr ) return setUserHooksPtr(userHooksPtrIn);
-    UserHooksVector* uhv = dynamic_cast<UserHooksVector*>(userHooksPtr);
-    if ( !uhv ) { uhv = new UserHooksVector();
+    shared_ptr<UserHooksVector> uhv =
+      dynamic_pointer_cast<UserHooksVector>(userHooksPtr);
+    if ( !uhv ) { uhv = make_shared<UserHooksVector>();
       uhv->hooks.push_back(userHooksPtr); userHooksPtr = uhv; }
-    uhv->hooks.push_back(userHooksPtrIn);
-    hasUserHooksVector = true; return true;}
+    uhv->hooks.push_back(userHooksPtrIn); return true;}
 
   // Possibility to pass in pointer for full merging class.
-  bool setMergingPtr( Merging* mergingPtrIn)
+  bool setMergingPtr( MergingPtr mergingPtrIn)
     { mergingPtr = mergingPtrIn; return true;}
 
   // Possibility to pass in pointer for merging hooks.
-  bool setMergingHooksPtr( MergingHooks* mergingHooksPtrIn)
+  bool setMergingHooksPtr( MergingHooksPtr mergingHooksPtrIn)
     { mergingHooksPtr = mergingHooksPtrIn; return true;}
 
   // Possibility to pass in pointer for beam shape.
-  bool setBeamShapePtr( BeamShape* beamShapePtrIn)
+  bool setBeamShapePtr( BeamShapePtr beamShapePtrIn)
     { beamShapePtr = beamShapePtrIn; return true;}
 
   // Possibility to pass in pointer(s) for external cross section,
@@ -164,27 +166,31 @@ public:
   bool setResonancePtr( ResonanceWidths* resonancePtrIn)
     { resonancePtrs.push_back( resonancePtrIn); return true;}
 
-  // Possibility to pass in pointer for external showers.
-  bool setShowerPtr( TimeShower* timesDecPtrIn,
-    TimeShower* timesPtrIn = 0, SpaceShower* spacePtrIn = 0)
+  //TS?? Possibility to pass in pointer for external showers. Obsolete!
+  bool setShowerPtr( TimeShowerPtr timesDecPtrIn,
+    TimeShowerPtr timesPtrIn = nullptr, SpaceShowerPtr spacePtrIn = nullptr)
     { timesDecPtr = timesDecPtrIn; timesPtr = timesPtrIn;
     spacePtr = spacePtrIn; return true;}
 
+  // Possibility to pass in pointer for external showers.
+  bool setShowerModelPtr( ShowerModelPtr showerModelPtrIn)
+    { showerModelPtr = showerModelPtrIn; return true;}
+
   // Possibility to pass in pointer for modelling of heavy ion collisions.
-  bool setHeavyIonsPtr( HeavyIons* heavyIonsPtrIn)
+  bool setHeavyIonsPtr( HeavyIonsPtr heavyIonsPtrIn)
     { heavyIonsPtr = heavyIonsPtrIn; return true;}
 
   // Possibility to pass a HIUserHooks pointer for modifying the
   // behavior of the heavy ion modelling.
-  bool setHIHooks(HIUserHooks* hiHooksPtrIn)
+  bool setHIHooks(HIUserHooksPtr hiHooksPtrIn)
     { hiHooksPtr = hiHooksPtrIn; return true; }
 
   // Possibility to get the pointer to a object modelling heavy ion
   // collisions.
-  HeavyIons* getHeavyIonsPtr() { return heavyIonsPtr;}
+  HeavyIonsPtr getHeavyIonsPtr() { return heavyIonsPtr;}
 
   // Possibility to pass in pointer for setting of parton space-time vertices.
-  bool setPartonVertexPtr( PartonVertex* partonVertexPtrIn)
+  bool setPartonVertexPtr( PartonVertexPtr partonVertexPtrIn)
     { partonVertexPtr = partonVertexPtrIn; return true;}
 
   // Initialize.
@@ -193,9 +199,15 @@ public:
   // Generate the next event.
   bool next();
 
+  // Generate the next event, either with new energies or new beam momenta.
+  bool next(double eCMin);
+  bool next(double eAin, double eBin);
+  bool next(double pxAin, double pyAin, double pzAin,
+            double pxBin, double pyBin, double pzBin);
+
   // Generate only a single timelike shower as in a decay.
   int forceTimeShower( int iBeg, int iEnd, double pTmax, int nBranchMax = 0)
-    {  partonSystems.clear(); info.setScalup( 0, pTmax);
+    {  partonSystems.clear(); infoPrivate.setScalup( 0, pTmax);
     return timesDecPtr->shower( iBeg, iEnd, event, pTmax, nBranchMax); }
 
   // Generate only the hadronization/decay stage.
@@ -207,6 +219,10 @@ public:
   // Special routine to force R-hadron decay when not done before.
   bool forceRHadronDecays() {return doRHadronDecays();}
 
+  // Do a low-energy collision between two hadrons in the event record.
+  bool doLowEnergyProcess(int i1, int i2, int type) {
+    return hadronLevel.doLowEnergyProcess( i1, i2, type, event); }
+
   // List the current Les Houches event.
   void LHAeventList() { if (lhaUpPtr != 0) lhaUpPtr->listEvent();}
 
@@ -225,210 +241,233 @@ public:
   string word(string key) {return settings.word(key);}
 
   // Auxiliary to set parton densities among list of possibilities.
-  PDF* getPDFPtr(int idIn, int sequence = 1, string beam = "",
+  PDFPtr getPDFPtr(int idIn, int sequence = 1, string beam = "",
     bool resolved = true);
 
   // The event record for the parton-level central process.
-  Event          process;
+  Event           process = {};
 
   // The event record for the complete event history.
-  Event          event;
+  Event           event = {};
 
-  // Information on the generation: current subprocess and error statistics.
-  Info           info;
+  // Public information and statistic on the generation.
+  const Info&     info = infoPrivate;
 
   // Settings: databases of flags/modes/parms/words to control run.
-  Settings       settings;
+  Settings        settings = {};
 
   // ParticleData: the particle data table/database.
-  ParticleData   particleData;
+  ParticleData    particleData = {};
 
   // Random number generator.
-  Rndm           rndm;
+  Rndm            rndm = {};
 
   // Standard Model couplings, including alphaS and alphaEM.
-  Couplings      couplings;
-  Couplings*     couplingsPtr;
+  CoupSM          coupSM = {};
+
+  // SUSY couplings.
+  CoupSUSY        coupSUSY = {};
 
   // SLHA Interface
-  SLHAinterface  slhaInterface;
+  SLHAinterface   slhaInterface = {};
 
   // The partonic content of each subcollision system (auxiliary to event).
-  PartonSystems  partonSystems;
+  PartonSystems   partonSystems = {};
 
   // Merging object as wrapper for matrix element merging routines.
-  Merging*       mergingPtr;
+  MergingPtr      mergingPtr = {};
 
   // Pointer to MergingHooks object for user interaction with the merging.
   // MergingHooks also more generally steers the matrix element merging.
-  MergingHooks*  mergingHooksPtr;
+  MergingHooksPtr  mergingHooksPtr;
 
   // Pointer to a HeavyIons object for generating heavy ion collisions
-  HeavyIons* heavyIonsPtr;
+  HeavyIonsPtr   heavyIonsPtr = {};
 
   // Pointer to a HIUserHooks object to modify heavy ion modelling.
-  HIUserHooks* hiHooksPtr;
+  HIUserHooksPtr hiHooksPtr = {};
 
   // The two incoming beams.
-  BeamParticle beamA;
-  BeamParticle beamB;
+  BeamParticle   beamA = {};
+  BeamParticle   beamB = {};
 
 private:
 
-  // Copy and = constructors are made private so they cannot be used.
-  Pythia(const Pythia&);
-  Pythia& operator=(const Pythia&);
+  // The main keeper/collector of information, accessible from all
+  // PhysicsBase objects. The information is available from the
+  // outside through the public info object.
+  Info infoPrivate = {};
+
+  // Initialise new Pythia object (called by constructors).
+  void initPtrs();
+
+  // Functions to be called at the beginning and end of a next() call.
+  void beginEvent();
+  void endEvent(PhysicsBase::Status status);
+
+  // Register a PhysicsBase object and give it a pointer to the info object.
+  void registerPhysicsBase(PhysicsBase & pb) { pb.initInfoPtr(infoPrivate);
+    physicsPtrs.push_back(&pb); }
+
+  // If new pointers are set in Info propagate this to all
+  // PhysicsBase objects.
+  void pushInfo();
 
   // Constants: could only be changed in the code itself.
   static const double VERSIONNUMBERHEAD, VERSIONNUMBERCODE;
-  static const int    NTRY, SUBRUNDEFAULT;
+  // Maximum number of tries to produce parton level from given input.
+  // Negative integer to denote that no subrun has been set.
+  static const int    NTRY = 10, SUBRUNDEFAULT = -999;
 
   // Initialization data, extracted from database.
-  string xmlPath;
-  bool   doProcessLevel, doPartonLevel, doHadronLevel, doSoftQCDall,
-         doSoftQCDinel, doCentralDiff, doDiffraction,
-         doSoftQCD, doVMDsideA, doVMDsideB, doHardDiff, doResDec,
-         doFSRinRes, decayRHadrons, abortIfVeto, checkEvent, checkHistory;
-  int    nErrList;
-  double epTolErr, epTolWarn, mTolErr, mTolWarn;
+  string xmlPath = {};
+  bool   doProcessLevel = {}, doPartonLevel = {}, doHadronLevel = {},
+         doSoftQCDall = {}, doSoftQCDinel = {}, doCentralDiff = {},
+         doDiffraction = {}, doSoftQCD = {}, doVMDsideA = {}, doVMDsideB = {},
+         doHardDiff = {}, doResDec = {}, doFSRinRes = {}, decayRHadrons = {},
+         abortIfVeto = {}, checkEvent = {}, checkHistory = {};
+  int    nErrList = {};
+  double epTolErr = {}, epTolWarn = {}, mTolErr = {}, mTolWarn = {};
 
   // Initialization data related to photon-photon interactions.
-  bool   beamHasGamma, beamAisResGamma, beamBisResGamma, beamAhasResGamma,
-         beamBhasResGamma;
-  int    gammaMode;
+  bool   beamHasGamma = {}, beamAisResGamma = {}, beamBisResGamma = {},
+         beamAhasResGamma = {},
+         beamBhasResGamma = {};
+  int    gammaMode = {};
 
   // Initialization data, extracted from init(...) call.
-  bool   isConstructed, isInit, isUnresolvedA, isUnresolvedB, showSaV,
-         showMaD, doReconnect, forceHadronLevelCR;
-  int    idA, idB, frameType, boostType, nCount, nShowLHA, nShowInfo,
-         nShowProc, nShowEvt, reconnectMode;
-  double mA, mB, pxA, pxB, pyA, pyB, pzA, pzB, eA, eB,
-         pzAcm, pzBcm, eCM, betaZ, gammaZ;
-  Vec4   pAinit, pBinit, pAnow, pBnow;
-  RotBstMatrix MfromCM, MtoCM;
+  bool   isConstructed = {}, isInit = {}, isUnresolvedA = {},
+         isUnresolvedB = {}, showSaV = {}, showMaD = {}, doReconnect = {},
+         forceHadronLevelCR = {};
+  int    idA = {}, idB = {}, frameType = {}, boostType = {}, nCount = {},
+         nShowLHA = {}, nShowInfo = {}, nShowProc = {}, nShowEvt = {},
+         reconnectMode = {};
+  double mA = {}, mB = {}, pxA = {}, pxB = {}, pyA = {}, pyB = {}, pzA = {},
+         pzB = {}, eA = {}, eB = {}, pzAcm = {}, pzBcm = {}, eCM = {},
+         betaZ = {}, gammaZ = {};
+  Vec4   pAinit = {}, pBinit = {}, pAnow = {}, pBnow = {};
+  RotBstMatrix MfromCM = {}, MtoCM = {};
 
   // information for error checkout.
-  int    nErrEvent;
-  vector<int> iErrId, iErrCol, iErrEpm, iErrNan, iErrNanVtx;
+  int    nErrEvent = {};
+  vector<int> iErrId = {}, iErrCol = {}, iErrEpm = {}, iErrNan = {},
+         iErrNanVtx = {};
 
   // Pointers to the parton distributions of the two incoming beams.
-  PDF* pdfAPtr;
-  PDF* pdfBPtr;
+  PDFPtr pdfAPtr = {};
+  PDFPtr pdfBPtr = {};
 
   // Extra PDF pointers to be used in hard processes only.
-  PDF* pdfHardAPtr;
-  PDF* pdfHardBPtr;
+  PDFPtr pdfHardAPtr = {};
+  PDFPtr pdfHardBPtr = {};
 
   // Extra Pomeron PDF pointers to be used in diffractive processes only.
-  PDF* pdfPomAPtr;
-  PDF* pdfPomBPtr;
+  PDFPtr pdfPomAPtr = {};
+  PDFPtr pdfPomBPtr = {};
 
   // Extra Photon PDF pointers to be used in lepton -> gamma processes.
-  PDF* pdfGamAPtr;
-  PDF* pdfGamBPtr;
+  PDFPtr pdfGamAPtr = {};
+  PDFPtr pdfGamBPtr = {};
 
   // Extra PDF pointers to be used in hard lepton -> gamma processes.
-  PDF* pdfHardGamAPtr;
-  PDF* pdfHardGamBPtr;
+  PDFPtr pdfHardGamAPtr = {};
+  PDFPtr pdfHardGamBPtr = {};
 
   // Alternative unresolved PDFs when mixing resolved and unresolved processes.
-  PDF* pdfUnresAPtr;
-  PDF* pdfUnresBPtr;
-  PDF* pdfUnresGamAPtr;
-  PDF* pdfUnresGamBPtr;
+  PDFPtr pdfUnresAPtr = {};
+  PDFPtr pdfUnresBPtr = {};
+  PDFPtr pdfUnresGamAPtr = {};
+  PDFPtr pdfUnresGamBPtr = {};
 
   // PDF pointers to externally provided photon fluxes.
-  PDF* pdfGamFluxAPtr;
-  PDF* pdfGamFluxBPtr;
+  PDFPtr pdfGamFluxAPtr = {};
+  PDFPtr pdfGamFluxBPtr = {};
 
   // Extra VMD PDF pointers to be used in SoftQCD with gammas.
-  PDF* pdfVMDAPtr;
-  PDF* pdfVMDBPtr;
-
-  // Keep track when "new" has been used and needs a "delete" for PDF's etc.
-  bool useNewPdfA, useNewPdfB, useNewPdfHard, useNewPdfPomA, useNewPdfPomB,
-    useNewPdfGamA, useNewPdfGamB, useNewPdfHardGamA, useNewPdfHardGamB,
-    useNewPdfUnresA, useNewPdfUnresB, useNewPdfUnresGamA, useNewPdfUnresGamB,
-    useNewPdfVMDA, useNewPdfVMDB, hasUserHooksVector;
+  PDFPtr pdfVMDAPtr = {};
+  PDFPtr pdfVMDBPtr = {};
 
   // Alternative Pomeron beam-inside-beam.
-  BeamParticle beamPomA;
-  BeamParticle beamPomB;
+  BeamParticle beamPomA = {};
+  BeamParticle beamPomB = {};
 
   // Alternative photon beam-inside-beam.
-  BeamParticle beamGamA;
-  BeamParticle beamGamB;
+  BeamParticle beamGamA = {};
+  BeamParticle beamGamB = {};
 
   // Alternative VMD beam-inside-beam.
-  BeamParticle beamVMDA;
-  BeamParticle beamVMDB;
+  BeamParticle beamVMDA = {};
+  BeamParticle beamVMDB = {};
 
   // LHAup object for generating external events.
-  bool   doLHA, useNewLHA;
-  LHAup* lhaUpPtr;
+  bool   doLHA = false;
+  bool   useNewLHA = false;
+  LHAupPtr lhaUpPtr = {};
 
   // Pointer to external decay handler and list of particles it handles.
-  DecayHandler* decayHandlePtr;
-  vector<int>   handledParticles;
+  DecayHandlerPtr decayHandlePtr = {};
+  vector<int>     handledParticles = {};
 
   // Pointer to UserHooks object for user interaction with program.
-  UserHooks* userHooksPtr;
-  bool       hasUserHooks, doVetoProcess, doVetoPartons, retryPartonLevel;
+  UserHooksPtr userHooksPtr = {};
+  bool       doVetoProcess = {}, doVetoPartons = {}, retryPartonLevel = {};
 
   // Pointer to BeamShape object for beam momentum and interaction vertex.
-  BeamShape* beamShapePtr;
-  bool       useNewBeamShape, doMomentumSpread, doVertexSpread;
+  BeamShapePtr beamShapePtr = {};
+  bool         doMomentumSpread = {}, doVertexSpread = {}, doVarEcm = {};
+  double     eMinPert = {}, eWidthPert = {};
 
   // Pointers to external processes derived from the Pythia base classes.
-  vector<SigmaProcess*> sigmaPtrs;
+  vector<SigmaProcess*> sigmaPtrs = {};
 
   // Pointers to external phase-space generators derived from Pythia
   // base classes.
-  vector<PhaseSpace*> phaseSpacePtrs;
+  vector<PhaseSpace*> phaseSpacePtrs = {};
 
   // Pointers to external calculation of resonance widths.
-  vector<ResonanceWidths*> resonancePtrs;
+  vector<ResonanceWidths*> resonancePtrs = {};
 
-  // Pointers to timelike and spacelike showers.
-  TimeShower*  timesDecPtr;
-  TimeShower*  timesPtr;
-  SpaceShower* spacePtr;
-  bool         useNewTimesDec, useNewTimes, useNewSpace;
+  // Pointers to timelike and spacelike showers, including Vinxia and Dire.
+  TimeShowerPtr  timesDecPtr = {};
+  TimeShowerPtr  timesPtr = {};
+  SpaceShowerPtr spacePtr = {};
+  ShowerModelPtr showerModelPtr = {};
 
   // Pointer to assign space-time vertices during parton evolution.
-  PartonVertex* partonVertexPtr;
-  bool          useNewPartonVertex;
+  PartonVertexPtr partonVertexPtr;
 
   // The main generator class to define the core process of the event.
-  ProcessLevel processLevel;
+  ProcessLevel processLevel = {};
 
   // The main generator class to produce the parton level of the event.
-  PartonLevel partonLevel;
+  PartonLevel partonLevel = {};
 
   // The main generator class to perform trial showers of the event.
-  PartonLevel trialPartonLevel;
+  PartonLevel trialPartonLevel = {};
 
   // Flags for defining the merging scheme.
-  bool        hasMerging, hasOwnMerging;
-  bool        hasMergingHooks, hasOwnMergingHooks, doMerging;
+  bool        doMerging = {};
+
+  // The StringInteractions class.
+  StringIntPtr stringInteractionsPtr;
 
   // The Colour reconnection class.
-  ColourReconnection colourReconnection;
+  ColRecPtr colourReconnectionPtr = {};
 
   // The junction spltiting class.
-  JunctionSplitting junctionSplitting;
+  JunctionSplitting junctionSplitting = {};
 
   // The main generator class to produce the hadron level of the event.
-  HadronLevel hadronLevel;
+  HadronLevel hadronLevel = {};
 
   // The total cross section class is used both on process and parton level.
-  SigmaTotal sigmaTot;
+  SigmaTotal sigmaTot = {};
 
   // The RHadrons class is used both at PartonLevel and HadronLevel.
-  RHadrons   rHadrons;
+  RHadrons   rHadrons = {};
 
   // Flags for handling generation of heavy ion collisons.
-  bool        hasHeavyIons, hasOwnHeavyIons, doHeavyIons;
+  bool        hasHeavyIons = {}, doHeavyIons = {};
 
   // Write the Pythia banner, with symbol and version information.
   void banner();
@@ -454,6 +493,9 @@ private:
   // Recalculate kinematics for each event when beam momentum has a spread.
   void nextKinematics();
 
+  // Simplified treatment for low-energy nonperturbative collisions.
+  bool nextNonPert();
+
   // Boost from CM frame to lab frame, or inverse. Set production vertex.
   void boostAndVertex(bool toLab, bool setVertex);
 
@@ -464,9 +506,12 @@ private:
   bool check();
 
   // Initialization of SLHA data.
-  bool initSLHA ();
+  bool initSLHA();
   stringstream particleDataBuffer;
 
+  // Keep track of and initialize all pointers to PhysicsBase-derived objects.
+  vector<PhysicsBase*> physicsPtrs = {};
+
 };
 
 //==========================================================================
