@@ -13,6 +13,7 @@
 #include "Pythia8/Event.h"
 #include "Pythia8/Info.h"
 #include "Pythia8/ParticleData.h"
+#include "Pythia8/PhysicsBase.h"
 #include "Pythia8/PythiaStdlib.h"
 #include "Pythia8/ResonanceWidths.h"
 #include "Pythia8/Settings.h"
@@ -24,18 +25,15 @@ namespace Pythia8 {
 // The ResonanceDecays class handles the sequential decay of resonances
 // that are part of the hard process (t, W, Z, H, SUSY,...).
 
-class ResonanceDecays {
+class ResonanceDecays : public PhysicsBase {
 
 public:
 
   // Constructor.
-  ResonanceDecays() : infoPtr(), particleDataPtr(), rndmPtr(), id0(), mult(),
-    m0() {}
+  ResonanceDecays() : id0(), mult(), m0() {}
 
   // Store pointers to Info and Rndm for error messages and random numbers.
-  void init(Info* infoPtrIn,  ParticleData* particleDataPtrIn,
-    Rndm* rndmPtrIn) {infoPtr = infoPtrIn;
-    particleDataPtr = particleDataPtrIn; rndmPtr = rndmPtrIn;}
+  void init() {}
 
   // Generate the next decay sequence.
   bool next( Event& process, int iDecNow = 0);
@@ -47,15 +45,6 @@ private:
   static const double MSAFETY, WIDTHCUT, TINY, TINYBWRANGE,
                       WTCORRECTION[11];
 
-  // Pointer to various information on the generation.
-  Info*         infoPtr;
-
-  // Pointer to the particle data table.
-  ParticleData* particleDataPtr;
-
-  // Pointer to the random number generator.
-  Rndm*         rndmPtr;
-
   // Select masses of decay products.
   bool pickMasses();
 
