@@ -141,6 +141,8 @@ public:
     ef2Save(), vf2Save(), af2Save(), efvfSave(), vf2af2Save(), VCKMsave(),
     V2CKMsave(), V2CKMout(), rndmPtr() {}
 
+  virtual ~CoupSM() {}
+
   // Initialize, normally from Pythia::init().
   void init(Settings& settings, Rndm* rndmPtrIn);
 
@@ -213,19 +215,6 @@ protected:
 
 //==========================================================================
 
-// Generic couplings class
-
-class Couplings : public CoupSM {
-
-public:
-
-  Couplings(bool isSUSYin = false) : isSUSY(isSUSYin) {}
-  bool isSUSY;
-
-};
-
-//==========================================================================
-
 } // end namespace Pythia8
 
 #endif // Pythia8_StandardModel_H
