@@ -2,7 +2,9 @@
 # Copyright (C) 2019 Torbjorn Sjostrand.
 # PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 # Please respect the MCnet Guidelines, see GUIDELINES for details.
-#
+
+# Keywords: basic usage; charged multiplicity; python;
+
 # This is a simple test program. It fits on one slide in a talk.  It
 # studies the charged multiplicity distribution at the LHC. To set the
 # path to the Pythia 8 Python interface do either (in a shell prompt):
@@ -22,6 +24,7 @@ sys.path.insert(0, lib)
 # Import the Pythia module.
 import pythia8
 pythia = pythia8.Pythia()
+print pythia.settings.fvec("Charmonium:gg2ccbar(3S1)[3S1(8)]g")
 pythia.readString("Beams:eCM = 8000.")
 pythia.readString("HardQCD:all = on")
 pythia.readString("PhaseSpace:pTHatMin = 20.")
