@@ -3,9 +3,12 @@
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
+// Authors: Juan Rojo <unavailable>.
+
+// Keywords: parton distribution; LHAPDF;
+
 // This program compares the internal and LHAPDF implementations of the
 // NNPDF 2.3 QCD+QED sets, for results and for timing.
-// Author: Juan Rojo.
 // Warning: this example is constructed to work for LHAPDF5.
 // There seem to be differences when instead comparing with LHAPDF6.
 
@@ -22,7 +25,7 @@ int main() {
 
   // Access the PDFs.
   int idBeamIn = 2212;
-  string xmlPath = "../xmldoc/";
+  string pdfPath = pythia.settings.word("xmlPath") + "../pdfdata";
   Info info;
 
   // Grid of studied points.
@@ -41,7 +44,7 @@ int main() {
   for (int iFitIn = 3; iFitIn < 5; iFitIn++) {
 
     // Constructor for internal PDFs.
-    NNPDF pdfs_nnpdf( idBeamIn, iFitIn, xmlPath, &info);
+    NNPDF pdfs_nnpdf( idBeamIn, iFitIn, pdfPath, &info);
 
     // Constructor for LHAPDF.
     if (iFitIn == 3) setName = "LHAPDF5:NNPDF23_nlo_as_0119_qed.LHgrid";
